==> rc-ui-lib-1.3.4.tgz: package/es/popover/Popover.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { forwardRef, useContext, useEffect, useImperativeHandle, useRef, useState } from 'react';
import classNames from 'classnames';
import { createPopper, offsetModifier } from '@vant/popperjs'; // component

import Popup from '../popup';
import Icon from '../icon'; // utils

import { extend, pick } from '../utils';
import { BORDER_BOTTOM } from '../utils/constant'; // hook

import useClickAway from '../hooks/use-click-away'; // type

import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var popupProps = ['overlay', 'duration', 'overlayStyle', 'overlayClass', 'closeOnClickOverlay', 'teleport', 'onClose', 'onOpen', 'onClosed', 'onOpened', 'onClickOverlay'];
var Popover = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('popover', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      updateShow = _useState2[1];

  var popper = useRef(null);
  var wrapperRef = useRef();
  var popoverRef = useRef();

  var createPopperInstance = function createPopperInstance() {
    return createPopper(wrapperRef.current, popoverRef.current.popupRef.current, {
      placement: props.placement,
      modifiers: [{
        name: 'computeStyles',
        options: {
          adaptive: false,
          gpuAcceleration: false
        }
      }, extend({}, offsetModifier, {
        options: {
          offset: props.offset
        }
      })]
    });
  };

  var onClickWrapper = function onClickWrapper() {
    if (props.trigger === 'click') {
      updateShow(!visible);
    }
  };

  var onClickAction = function onClickAction(action, index) {
    var _props$onSelect;

    if (action.disabled) {
      return;
    }

    (_props$onSelect = props.onSelect) === null || _props$onSelect === void 0 ? void 0 : _props$onSelect.call(props, action, index);

    if (props.closeOnClickAction) {
      updateShow(false);
    }
  };

  var onClickAway = function onClickAway() {
    if (!props.overlay || props.closeOnClickOverlay) {
      updateShow(false);
    }
  };

  var renderAction = function renderAction(action, index) {
    var icon = action.icon,
        text = action.text,
        color = action.color,
        disabled = action.disabled,
        actionClassname = action.className;
    return /*#__PURE__*/React.createElement("div", {
      // role="menuitem"
      key: index,
      className: classNames(bem('action', {
        disabled: disabled,
        'with-icon': icon
      }), actionClassname),
      style: {
        color: color
      },
      tabIndex: disabled ? undefined : 0,
      "aria-disabled": disabled || undefined,
      onClick: function onClick() {
        return onClickAction(action, index);
      }
    }, icon && /*#__PURE__*/React.createElement(Icon, {
      name: icon,
      classPrefix: props.iconPrefix,
      className: classNames(bem('action-icon'))
    }), /*#__PURE__*/React.createElement("div", {
      className: classNames(bem('action-text'), BORDER_BOTTOM)
    }, text));
  };

  useEffect(function () {
    return function () {
      if (popper.current) {
        var _popper$current;

        (_popper$current = popper.current) === null || _popper$current === void 0 ? void 0 : _popper$current.destroy();
        popper.current = null;
      }
    };
  }, []);
  useEffect(function () {
    var updateLocation = function updateLocation() {
      if (!visible) {
        return;
      }

      if (!popper.current) {
        popper.current = createPopperInstance();
      } else {
        var _popper$current2;

        (_popper$current2 = popper.current) === null || _popper$current2 === void 0 ? void 0 : _popper$current2.setOptions({
          placement: props.placement
        });
      }
    };

    updateLocation();
  }, [visible, props.placement]);
  useEffect(function () {
    var popupTarget;

    var prevent = function prevent(e) {
      return e.stopPropagation();
    };

    if (popoverRef.current && popoverRef.current.popupRef.current) {
      popupTarget = popoverRef.current.popupRef.current;
      popupTarget.addEventListener('touchstart', prevent);
    }

    return function () {
      if (popupTarget) popupTarget.removeEventListener('touchstart', prevent);
    };
  }, [popoverRef.current]);
  useImperativeHandle(ref, function () {
    return {
      show: function show() {
        if (visible) {
          updateShow(false);
          setTimeout(function () {
            return updateShow(true);
          }, 0);
          return;
        }

        updateShow(true);
      },
      hide: function hide() {
        return updateShow(false);
      }
    };
  });
  useClickAway(wrapperRef, onClickAway, 'touchstart', props.closeOnClickOutside);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
    ref: wrapperRef,
    className: classNames(bem('wrapper')),
    onClick: onClickWrapper
  }, props.reference), /*#__PURE__*/React.createElement(Popup, _extends({
    ref: popoverRef,
    visible: visible,
    className: classNames(bem([props.theme])),
    position: "",
    transition: "rc-zoom",
    lockScroll: false
  }, pick(props, popupProps)), /*#__PURE__*/React.createElement("div", {
    className: classNames(bem('arrow'))
  }), /*#__PURE__*/React.createElement("div", {
    role: "menu",
    className: classNames(bem('content'))
  }, props.children || props.actions.map(renderAction))));
});
Popover.defaultProps = {
  overlay: false,
  duration: 300,
  closeOnClickAction: true,
  closeOnClickOverlay: true,
  closeOnClickOutside: true,
  offset: [0, 8],
  theme: 'light',
  trigger: 'click',
  actions: [],
  placement: 'bottom'
};
Popover.displayName = 'Popover';
export default Popover;

==> rc-ui-lib-1.3.5.tgz: package/es/popover/Popover.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { forwardRef, useContext, useEffect, useImperativeHandle, useRef, useState } from 'react';
import classNames from 'classnames';
import { createPopper, offsetModifier } from '@vant/popperjs';
// component
import Popup from '../popup';
import Icon from '../icon';
// utils
import { extend, pick } from '../utils';
import { BORDER_BOTTOM } from '../utils/constant';
// hook
import useClickAway from '../hooks/use-click-away';
// type

import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var popupProps = ['overlay', 'duration', 'overlayStyle', 'overlayClass', 'closeOnClickOverlay', 'teleport', 'onClose', 'onOpen', 'onClosed', 'onOpened', 'onClickOverlay'];
var Popover = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
    prefixCls = _useContext.prefixCls,
    createNamespace = _useContext.createNamespace;
  var _createNamespace = createNamespace('popover', prefixCls),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    updateShow = _useState2[1];
  var popper = useRef(null);
  var wrapperRef = useRef();
  var popoverRef = useRef();
  var createPopperInstance = function createPopperInstance() {
    return createPopper(wrapperRef.current, popoverRef.current.popupRef.current, {
      placement: props.placement,
      modifiers: [{
        name: 'computeStyles',
        options: {
          adaptive: false,
          gpuAcceleration: false
        }
      }, extend({}, offsetModifier, {
        options: {
          offset: props.offset
        }
      })]
    });
  };
  var onClickWrapper = function onClickWrapper() {
    if (props.trigger === 'click') {
      updateShow(!visible);
    }
  };
  var onClickAction = function onClickAction(action, index) {
    var _props$onSelect;
    if (action.disabled) {
      return;
    }
    (_props$onSelect = props.onSelect) === null || _props$onSelect === void 0 ? void 0 : _props$onSelect.call(props, action, index);
    if (props.closeOnClickAction) {
      updateShow(false);
    }
  };
  var onClickAway = function onClickAway() {
    if (!props.overlay || props.closeOnClickOverlay) {
      updateShow(false);
    }
  };
  var renderAction = function renderAction(action, index) {
    var icon = action.icon,
      text = action.text,
      color = action.color,
      disabled = action.disabled,
      actionClassname = action.className;
    return /*#__PURE__*/React.createElement("div", {
      // role="menuitem"
      key: index,
      className: classNames(bem('action', {
        disabled: disabled,
        'with-icon': icon
      }), actionClassname),
      style: {
        color: color
      },
      tabIndex: disabled ? undefined : 0,
      "aria-disabled": disabled || undefined,
      onClick: function onClick() {
        return onClickAction(action, index);
      }
    }, icon && /*#__PURE__*/React.createElement(Icon, {
      name: icon,
      classPrefix: props.iconPrefix,
      className: classNames(bem('action-icon'))
    }), /*#__PURE__*/React.createElement("div", {
      className: classNames(bem('action-text'), BORDER_BOTTOM)
    }, text));
  };
  useEffect(function () {
    return function () {
      if (popper.current) {
        var _popper$current;
        (_popper$current = popper.current) === null || _popper$current === void 0 ? void 0 : _popper$current.destroy();
        popper.current = null;
      }
    };
  }, []);
  useEffect(function () {
    var updateLocation = function updateLocation() {
      if (!visible) {
        return;
      }
      if (!popper.current) {
        popper.current = createPopperInstance();
      } else {
        var _popper$current2;
        (_popper$current2 = popper.current) === null || _popper$current2 === void 0 ? void 0 : _popper$current2.setOptions({
          placement: props.placement
        });
      }
    };
    updateLocation();
  }, [visible, props.placement]);
  useEffect(function () {
    var popupTarget;
    var prevent = function prevent(e) {
      return e.stopPropagation();
    };
    if (popoverRef.current && popoverRef.current.popupRef.current) {
      popupTarget = popoverRef.current.popupRef.current;
      popupTarget.addEventListener('touchstart', prevent);
    }
    return function () {
      if (popupTarget) popupTarget.removeEventListener('touchstart', prevent);
    };
  }, [popoverRef.current]);
  useImperativeHandle(ref, function () {
    return {
      show: function show() {
        if (visible) {
          updateShow(false);
          setTimeout(function () {
            return updateShow(true);
          }, 0);
          return;
        }
        updateShow(true);
      },
      hide: function hide() {
        return updateShow(false);
      }
    };
  });
  useClickAway(wrapperRef, onClickAway, 'touchstart', props.closeOnClickOutside);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
    ref: wrapperRef,
    className: classNames(bem('wrapper')),
    onClick: onClickWrapper
  }, props.reference), /*#__PURE__*/React.createElement(Popup, _extends({
    ref: popoverRef,
    visible: visible,
    className: classNames(bem([props.theme])),
    position: "",
    transition: "rc-zoom",
    lockScroll: false
  }, pick(props, popupProps)), /*#__PURE__*/React.createElement("div", {
    className: classNames(bem('arrow'))
  }), /*#__PURE__*/React.createElement("div", {
    role: "menu",
    className: classNames(bem('content'))
  }, props.children || props.actions.map(renderAction))));
});
Popover.defaultProps = {
  overlay: false,
  duration: 300,
  closeOnClickAction: true,
  closeOnClickOverlay: true,
  closeOnClickOutside: true,
  offset: [0, 8],
  theme: 'light',
  trigger: 'click',
  actions: [],
  placement: 'bottom'
};
Popover.displayName = 'Popover';
export default Popover;
